;;;
;;; Load the cl-unicode system so that files generated by its
;;; build-dependency :build[cl-unicode system are available when packaging.
;;;

(require :asdf)
;(asdf:load-system :asdf)                ; upgrade
(setf asdf:*central-registry*
      (list* '*default-pathname-defaults* asdf:*central-registry*))
(asdf:load-system :cl-unicode)
(quit)
